@@ -7,9 +7,9 @@ from typing import Optional
 
 import click
 
-from .input_args import generate_args
-from .middlewares import Middlewares
-from .parse_ast import generate_bindings_json
+from uipath_sdk._cli._utils._input_args import generate_args
+from uipath_sdk._cli._utils._parse_ast import generate_bindings_json
+from uipath_sdk._cli.middlewares import Middlewares
 
 
 def generate_env_file(target_directory):
