@@ -4,8 +4,9 @@ from .assets_service import AssetsService
 from .buckets_service import BucketsService
 from .connections_service import ConnectionsService
 from .context_grounding_service import ContextGroundingService
+from .jobs_service import JobsService
 from .processes_service import ProcessesService
-from .queues_services import QueuesService
+from .queues_service import QueuesService
 
 __all__ = [
     "ActionsService",
@@ -16,4 +17,5 @@ __all__ = [
     "ProcessesService",
     "ApiClient",
     "QueuesService",
+    "JobsService",
 ]
