@@ -3,6 +3,7 @@ from ._infer_bindings import get_inferred_bindings_names, infer_bindings
 from ._logs import setup_logging
 from ._request_override import header_folder
 from ._request_spec import RequestSpec
+from ._user_agent import header_user_agent, user_agent_value
 
 __all__ = [
     "Endpoint",
@@ -11,4 +12,6 @@ __all__ = [
     "header_folder",
     "get_inferred_bindings_names",
     "infer_bindings",
+    "header_user_agent",
+    "user_agent_value",
 ]
